@@ -336,7 +336,7 @@ ACCOUNT_DEFAULT_HTTP_PROTOCOL = env("ACCOUNT_DEFAULT_HTTP_PROTOCOL", default="ht
 # CSRF
 if DEBUG:
     CSRF_COOKIE_DOMAIN = None
-    CSRF_TRUSTED_ORIGINS = []
+    CSRF_TRUSTED_ORIGINS = ['*']
 #else:
 #    CSRF_COOKIE_DOMAIN = COOKIE_DOMAIN
 #    CSRF_TRUSTED_ORIGINS = ['.{0}'.format(COOKIE_DOMAIN)]
