@@ -12,6 +12,7 @@ from ....permissions import is_django_staff
 from ...devices.models import Device
 from ...groups.models import Group
 from ...profiles.models import Profile
+from ...profiles.utils import get_or_create_user_profile
 from ..utils import delete_apigw_consumer, create_apigw_consumer_jwt, delete_apigw_consumer_jwt, \
                     create_apigw_consumer_acl, delete_apigw_consumer_acl, get_profile_apigw_consumer_id, \
                     get_apigw_consumer_acls
@@ -21,6 +22,7 @@ logger = logging.getLogger('django_sso_app.core.apps.api_gateway')
 User = get_user_model()
 adapter = get_adapter()
 
+
 # device
 
 @receiver(pre_save, sender=Device)
@@ -67,14 +69,15 @@ def delete_device_api_jwt(sender, instance, **kwargs):
             raise Exception(
                 "Error deleting apigw consumer jwt, {}".format(status_code))
 
+
 # profile
 
 @receiver(pre_delete, sender=Profile)
 def delete_apigw_profile_consumer(sender, instance, **kwargs):
-    user = instance.user
+    profile = instance
+    user = profile.user
 
     if not is_django_staff(user):
-        profile = instance
         logger.info('Profile "{}" will be deleted, removing api gateway consumer'.format(profile))
 
         status_code, r1 = delete_apigw_consumer(profile)
@@ -89,53 +92,54 @@ def delete_apigw_profile_consumer(sender, instance, **kwargs):
                 raise Exception(
                     "Error deleting apigw consumer, {}".format(status_code))
 
+
 # group
 
-@receiver(m2m_changed)
-def signal_handler_when_profile_is_added_to_or_removed_from_group(action, instance, pk_set, model, **kwargs):
-    is_loaddata = getattr(instance, '__dssoa__loaddata', False)
+@receiver(m2m_changed, sender=Profile.groups.through)
+def api_gateway_signal_handler_when_profile_is_added_to_or_removed_from_group(action, instance, pk_set, **kwargs):
 
-    if model == Group and instance.__class__ == Profile:
-        profile = instance
-        user = profile.user
+    profile = instance
+    user = profile.user
 
-        if not is_django_staff(user):
-            if action == 'pre_add':
+    if not is_django_staff(user):
+        is_loaddata = getattr(user, '__dssoa__loaddata', False)
 
-                # do not create acl groups for signing up users
-                if user.last_login is None:
-                    logger.info('do not create acl groups while user never logged in')
-                    return
+        if action == 'pre_add':
 
-                for pk in pk_set:
-                    group = Group.objects.get(id=pk)
+            # do not create acl groups for signing up users
+            if user.last_login is None:
+                logger.info('do not create acl groups while user never logged in')
+                return
 
-                    logger.info('creating api gateway acl group "{}" for profile "{}"'.format(group, profile))
+            for pk in pk_set:
+                group = Group.objects.get(id=pk)
 
-                    status_code, resp = create_apigw_consumer_acl(profile, group.name)
+                logger.info('creating api gateway acl group "{}" for profile "{}"'.format(group, profile))
 
-                    if status_code < 400:
-                        logger.info('api gateway acl group created {}, {}'.format(status_code, resp))
+                status_code, resp = create_apigw_consumer_acl(profile, group.name)
 
-                        if not is_loaddata:
-                            profile.update_rev(True)
-                    else:
-                        logger.exception('error ({}) creating api gateway acl group'.format(status_code))
+                if status_code < 400:
+                    logger.info('api gateway acl group created {}, {}'.format(status_code, resp))
 
-            elif action == 'pre_remove':
-                for pk in pk_set:
-                    group = Group.objects.get(id=pk)
-                    logger.info('deleting apigw acl group "{}" for "{}"'.format(group, profile))
+                    if not is_loaddata:
+                        profile.update_rev(True)
+                else:
+                    logger.exception('error ({}) creating api gateway acl group'.format(status_code))
 
-                    status_code, resp = delete_apigw_consumer_acl(profile, group.name)
+        elif action == 'pre_remove':
+            for pk in pk_set:
+                group = Group.objects.get(id=pk)
+                logger.info('deleting apigw acl group "{}" for "{}"'.format(group, profile))
 
-                    if status_code < 400:
-                        logger.info('"{}" DELETED, updating profile sso_rev'.format(group))
+                status_code, resp = delete_apigw_consumer_acl(profile, group.name)
 
-                        if not is_loaddata:
-                            profile.update_rev(True)
-                    else:
-                        logger.exception('error ({}) deleting api gateway acl group'.format(status_code))
+                if status_code < 400:
+                    logger.info('"{}" DELETED, updating profile sso_rev'.format(group))
+
+                    if not is_loaddata:
+                        profile.update_rev(True)
+                else:
+                    logger.exception('error ({}) deleting api gateway acl group'.format(status_code))
 
 
 @receiver(user_logged_in)
@@ -143,10 +147,9 @@ def post_user_login(**kwargs):
     user = kwargs['user']
 
     if not is_django_staff(user):
-        # request = kwargs['request']
-        profile = user.sso_app_profile
-
+        profile = get_or_create_user_profile(user, commit=True)
         apigateway_consumer_id = get_profile_apigw_consumer_id(profile)
+
         logger.info('apigateway_consumer_id on login "{}"'.format(apigateway_consumer_id))
 
         _status, apigateway_acl_response = get_apigw_consumer_acls(profile)
