@@ -6,12 +6,12 @@ from django.test import Client
 from django.urls import reverse
 from rest_framework import status
 
-from .....backend.tests.factories import UserTestCase
+from django_sso_app.core.tests.factories import UserTestCase
 
 User = get_user_model()
 
 
 class TestApiGateway(UserTestCase):
 
-    def check_gateway_is_enabled(self):
+    def check_apigateway_is_enabled(self):
         pass
